@@ -258,16 +258,6 @@ public final class SMTPProperties extends AbstractProtocolProperties implements
         return transportProperties.getReferencedPartLimit();
     }
 
-    @Override
-    public boolean isEnforceSecureConnection() {
-        return transportProperties.isEnforceSecureConnection();
-    }
-
-    @Override
-    public void setEnforceSecureConnection(boolean enforceSecureConnection) {
-        transportProperties.setEnforceSecureConnection(enforceSecureConnection);
-    }
-
     @Override
     public String getSSLProtocols() {
         return sslProtocols;
